# Changelog

## Version 0.2.0

- chore: Remove Python 3.8 (EOL).
- precommit: Replace docformatter with ruff's formatter.

## Version 0.1.0

- Added parser to extract nodes and their lineages from OWL files.
